@@ -31,7 +31,6 @@
 
 #include "goatpaccountlinker.h"
 #include "goa/goa.h"
-#include "goabackend/goalogging.h"
 #include "goabackend/goautils.h"
 
 #define GOA_TP_ACCOUNT_LINKER_GET_PRIVATE(obj) \
@@ -90,7 +89,7 @@ goa_account_chat_disabled_changed_cb (GoaAccount         *goa_account,
   tp_enabled = tp_account_is_enabled (tp_account);
   if (tp_enabled != goa_enabled)
     {
-      goa_info ("The GOA account %s (Telepathy object path: %s) has been %s, "
+      g_info ("The GOA account %s (Telepathy object path: %s) has been %s, "
           "propagating to Telepathy",
           goa_account_get_id (goa_account), id,
           goa_enabled ? "enabled" : "disabled");
@@ -120,7 +119,7 @@ tp_account_chat_enabled_changed_cb (TpAccount          *tp_account,
   tp_enabled = tp_account_is_enabled (tp_account);
   if (tp_enabled != goa_enabled)
     {
-      goa_info ("The Telepathy account %s has been %s, propagating to GOA",
+      g_info ("The Telepathy account %s has been %s, propagating to GOA",
           id, tp_enabled ? "enabled" : "disabled");
       /* When we set this property, the autogenerated code emits a notify
        * signal immediately even if the property hasn't changed, so
@@ -148,7 +147,7 @@ goa_account_created_cb (GoaManager   *manager,
   if (!goa_manager_call_add_account_finish (manager,
         &goa_account_object_path, res, &error))
     {
-      goa_error ("Failed to create a GOA account for %s: %s (%s, %d)",
+      g_critical ("Failed to create a GOA account for %s: %s (%s, %d)",
           get_id_from_tp_account (tp_account),
           error->message,
           g_quark_to_string (error->domain),
@@ -157,7 +156,7 @@ goa_account_created_cb (GoaManager   *manager,
       goto out;
     }
 
-  goa_info ("Created new %s GOA account for Telepathy account %s",
+  g_info ("Created new %s GOA account for Telepathy account %s",
       goa_account_object_path, get_id_from_tp_account (tp_account));
 
  out:
@@ -173,7 +172,7 @@ create_goa_account (GoaTpAccountLinker *self,
   GVariantBuilder details;
   gchar *provider;
 
-  goa_info ("Creating new GOA account for Telepathy account %s",
+  g_info ("Creating new GOA account for Telepathy account %s",
       get_id_from_tp_account (tp_account));
 
   g_variant_builder_init (&credentials, G_VARIANT_TYPE_VARDICT);
@@ -226,17 +225,17 @@ tp_account_added (GoaTpAccountLinker *self,
   if (g_strcmp0 (tp_account_get_storage_provider (tp_account),
         "org.gnome.OnlineAccounts") == 0)
     {
-      goa_debug ("Skipping Telepathy account %s as it's handled directly by GOA", id);
+      g_debug ("Skipping Telepathy account %s as it's handled directly by GOA", id);
       return;
     }
 
   if (is_account_filtered (tp_account))
     {
-      goa_debug ("The account %s is ignored for debugging reasons", id);
+      g_debug ("The account %s is ignored for debugging reasons", id);
       return;
     }
 
-  goa_debug ("Telepathy account found: %s", id);
+  g_debug ("Telepathy account found: %s", id);
 
   g_hash_table_replace (priv->tp_accounts, g_strdup (id),
       g_object_ref (tp_account));
@@ -248,13 +247,13 @@ tp_account_added (GoaTpAccountLinker *self,
   goa_object = g_hash_table_lookup (priv->goa_accounts, id);
   if (goa_object == NULL)
     {
-      goa_debug ("Found a Telepathy account with no corresponding "
+      g_debug ("Found a Telepathy account with no corresponding "
           "GOA account: %s", id);
       create_goa_account (self, tp_account);
     }
   else
     {
-      goa_debug ("Found a Telepathy account with a matching "
+      g_debug ("Found a Telepathy account with a matching "
           "GOA account: %s", id);
       /* Make sure the initial state is synced. */
       tp_account_chat_enabled_changed_cb (tp_account, NULL, self);
@@ -272,7 +271,7 @@ goa_account_removed_by_us_cb (GObject      *object,
 
   if (!goa_account_call_remove_finish (goa_account, res, &error))
     {
-      goa_error ("Error removing GOA account %s (Telepathy object path: %s): "
+      g_critical ("Error removing GOA account %s (Telepathy object path: %s): "
           "%s (%s, %d)",
           goa_account_get_id (goa_account),
           get_id_from_goa_account (goa_account),
@@ -301,18 +300,18 @@ tp_account_removed_cb (TpAccountManager *manager,
        * 3 - "account-removed" is emitted by the account manager
        * 4 - tp_account_removed_cb is called for an unknown account
        */
-      goa_debug ("Ignoring removal of Telepathy account we asked to "
+      g_debug ("Ignoring removal of Telepathy account we asked to "
           "remove (%s)", id);
       return;
     }
 
-  goa_info ("Telepathy account %s removed, removing corresponding "
+  g_info ("Telepathy account %s removed, removing corresponding "
       "GOA account", id);
 
   goa_object = g_hash_table_lookup (priv->goa_accounts, id);
   if (goa_object == NULL)
     {
-      goa_error ("There is no GOA account for removed Telepathy "
+      g_critical ("There is no GOA account for removed Telepathy "
           "account %s", id);
       return;
     }
@@ -349,7 +348,7 @@ goa_account_added_cb (GoaClient *client,
     return;
 
   id = get_id_from_goa_account (goa_account);
-  goa_debug ("GOA account %s for Telepathy account %s added",
+  g_debug ("GOA account %s for Telepathy account %s added",
       goa_account_get_id (goa_account), id);
 
   g_signal_connect_object (goa_account, "notify::chat-disabled",
@@ -378,7 +377,7 @@ tp_account_removed_by_us_cb (GObject      *object,
 
   if (!tp_account_remove_finish (tp_account, res, &error))
     {
-      goa_error ("Error removing Telepathy account %s: %s (%s, %d)",
+      g_critical ("Error removing Telepathy account %s: %s (%s, %d)",
           get_id_from_tp_account (tp_account),
           error->message,
           g_quark_to_string (error->domain),
@@ -410,21 +409,21 @@ goa_account_removed_cb (GoaClient *client,
        * 3 - "account-removed" is emitted by the GOA client
        * 4 - goa_account_removed_cb is called for an unknown account
        */
-      goa_debug ("Ignoring removal of GOA account we asked to remove "
+      g_debug ("Ignoring removal of GOA account we asked to remove "
           "(%s, Telepathy object path: %s)",
           goa_account_get_id (goa_account),
           id);
       return;
     }
 
-  goa_info ("GOA account %s for Telepathy account %s removed, "
+  g_info ("GOA account %s for Telepathy account %s removed, "
       "removing Telepathy account",
       goa_account_get_id (goa_account), id);
 
   tp_account = g_hash_table_lookup (priv->tp_accounts, id);
   if (tp_account == NULL)
     {
-      goa_error ("There is no Telepathy account for removed GOA "
+      g_critical ("There is no Telepathy account for removed GOA "
           "account %s (Telepathy object path: %s)",
           goa_account_get_id (goa_account), id);
       return;
@@ -452,7 +451,7 @@ start_if_ready (GoaTpAccountLinker *self)
       return;
     }
 
-  goa_debug ("Both GOA and Tp are ready, starting tracking of accounts");
+  g_debug ("Both GOA and Tp are ready, starting tracking of accounts");
 
   /* GOA */
   goa_accounts = goa_client_get_accounts (priv->goa_client);
@@ -486,7 +485,7 @@ start_if_ready (GoaTpAccountLinker *self)
 
       if (!g_hash_table_lookup (priv->tp_accounts, id))
         {
-          goa_warning ("The Telepathy account %s was removed while the daemon "
+          g_warning ("The Telepathy account %s was removed while the daemon "
               "was not running, removing the corresponding GOA account", id);
           goa_account_call_remove (goa_object_peek_account (goa_object),
               NULL, /* cancellable */
@@ -506,12 +505,12 @@ account_manager_prepared_cb (GObject      *object,
 
   if (!tp_proxy_prepare_finish (object, res, &error))
     {
-      goa_error ("Error preparing AM: %s", error->message);
+      g_critical ("Error preparing AM: %s", error->message);
       g_clear_error (&error);
       return;
     }
 
-  goa_debug("Telepathy account manager prepared");
+  g_debug("Telepathy account manager prepared");
   start_if_ready (self);
 }
 
@@ -527,12 +526,12 @@ goa_client_new_cb (GObject      *object,
   priv->goa_client = goa_client_new_finish (result, &error);
   if (priv->goa_client == NULL)
     {
-      goa_error ("Error connecting to GOA: %s", error->message);
+      g_critical ("Error connecting to GOA: %s", error->message);
       g_clear_error (&error);
       return;
     }
 
-  goa_debug("GOA client ready");
+  g_debug("GOA client ready");
   start_if_ready (self);
 }
 
@@ -556,7 +555,7 @@ goa_tp_account_linker_init (GoaTpAccountLinker *self)
 {
   GoaTpAccountLinkerPrivate *priv;
 
-  goa_debug ("Starting GOA <-> Telepathy account linker");
+  g_debug ("Starting GOA <-> Telepathy account linker");
 
   self->priv = GOA_TP_ACCOUNT_LINKER_GET_PRIVATE (self);
   priv = self->priv;
